@@ -14,6 +14,9 @@ class OpencvDecoder(DLDSDecoder):
         image = cv2.cvtColor(image, cv2.COLOR_BGR2RGB)
         return image
 
+    def __reduce__(self):
+        return (OpencvDecoder, ())
+
     @staticmethod
     def get_file_extensions() -> List[str]:
         return ['bmp', 'dib', 'jpeg', 'jpg', 'jpe', 'jp2', 'png', 'pdm', 'pgm', 'ppm', 'sr', 'ras', 'tiff', 'tif']
