@@ -39,6 +39,10 @@ class DLDSClient:
     def __init__(self, username=None, password=None, auth_token=None, http_retries=10, parallel_requests=16,
                  base_url='https://api.vision.data-spree.com/api'):
 
+        self.username = username
+        self.password = password
+        self.auth_token = auth_token
+
         self.auth = None
         if auth_token is not None:
             self.auth = HTTPTokenAuth(auth_token)
@@ -61,6 +65,14 @@ class DLDSClient:
         self.http.mount('http://', adapter)
         self.http.mount('https://', adapter)
 
+    def __reduce__(self):
+        return (DLDSClient, (self.username,
+                             self.password,
+                             self.auth_token,
+                             self.http_retries,
+                             self.parallel_requests,
+                             self.base_url,))
+
     def download_dataset(self, directory, dataset_id, n_items=-1, accepted_status=None):
         """Download a dataset from data spree vision platform.
 
@@ -189,13 +201,8 @@ class DLDSClient:
                 json.dump(annotations, f, indent=2)
 
         if return_item:
-            item_to_return = {
-                'id': item_details['id'],
-                'dataset_id': item_details['dataset_id'],
-                'image': image_bytes,
-                'annotations': item_details['annotations']
-            }
-            return item_to_return
+            item_details['image'] = image_bytes
+            return item_details
 
         return None
 
