@@ -136,7 +136,7 @@ class DLDSDataLoader:
                                  self._dataset_directory,
                                  self._mode,
                                  self._allowed_status,
-                                 self._decoders,
+                                 self._decoders[0] if len(self._decoders) > 0 else None,
                                  self._distinct_items_per_category,))
 
     def add_decoder(self, decoder):
